class Measurement(object):
    def __init__(self, value, unit):
        self.value = value
        self.unit = unit

    def can_be_converted_to(self, other_unit):
        return self.unit.__class__.unit_name() == other_unit.__class__.unit_name()

    def value_converted_to(self, unit):
        if not self.can_be_converted_to(unit):
            raise TypeError('Unable to convert') # TODO set unit names in the exception

        base_unit_value = self.unit.converter.base_unit_value_from_value(self.value)
        return unit.converter.value_from_base_unit_value(base_unit_value)

    def convert_to(self, unit):
        self.value = self.value_converted_to(unit)
        self.unit = unit

    def converted_to(self, unit):
        return Measurement(self.value_converted_to(unit), unit)

    def to_string(self):
        return '{} {}'.format(self.value, self.unit.symbol)

    def __repr__(self):
        return '<aegon.Measurement {}>'.format(self.to_string())

    def __add__(self, other):
        if not isinstance(other, Measurement):
            raise TypeError('Expected type Measurement')

        # Trying to add two measurements of the same unit
        if self.unit == other.unit:
            return Measurement(self.value + other.value, self.unit)

        # Trying to add two measurements of different units, but the same dimension
        if self.can_be_converted_to(other.unit):
            other_converted = other.converted_to(self.unit)
            return self + other_converted
        else:
            raise Exception('Trying to add incompatible units')

    def __sub__(self, other):
        if not isinstance(other, Measurement):
            raise TypeError('Expected type Measurement')

        # Trying to subtract two measurements of the same unit
        if self.unit == other.unit:
            return Measurement(self.value - other.value, self.unit)

        # Trying to add two measurements of different units, but the same dimension
        if self.can_be_converted_to(other.unit):
            other_converted = other.converted_to(self.unit)
            return self - other_converted
        else:
            raise Exception('Trying to subtract incompatible units')

    def __mul__(self, other):
        if isinstance(other, int) or isinstance(other, float):
            return Measurement(self.value * other, self.unit)
        else:
            raise TypeError('Can only multiply with a number (int or float)')

    def __div__(self, other):
        if isinstance(other, int) or isinstance(other, float):
            return Measurement(self.value / other, self.unit)
        else:
            raise TypeError('Can only divide with a number (int or float)')

    def __floordiv__(self, other):
        return self.__div__(other)

    def __truediv__(self, other):
        return self.__div__(other)

