# coding=utf-8
from aegon import Unit, UnitConverterLinear
from aegon.utils import classproperty


class Length(Unit):
    def __init__(self, symbol, coefficient):
        super(Length, self).__init__(symbol, UnitConverterLinear(coefficient))

    @classmethod
    def unit_name(cls):
        return 'Length'

    @classmethod
    def base_unit(cls):
        return cls.meters


    @classproperty
    def megameters(cls):
        return Length('Mm', 1e6)

    @classproperty
    def kilometers(cls):
        return Length('km', 1e3)

    @classproperty
    def hectometers(cls):
        return Length('hm', 1e2)

    @classproperty
    def decameters(cls):
        return Length('dam', 1e1)

    @classproperty
    def meters(cls):
        return Length('m', 1.0)

    @classproperty
    def decimeters(cls):
        return Length('dm', 1e-1)

    @classproperty
    def centimeters(cls):
        return Length('cm', 1e-2)

    @classproperty
    def millimeters(cls):
        return Length('mm', 1e-3)

    @classproperty
    def micrometers(cls):
        return Length('µm', 1e-6)

    @classproperty
    def nanometers(cls):
        return Length('nm', 1e-9)

    @classproperty
    def picometers(cls):
        return Length('pm', 1e-12)

    @classproperty
    def inches(cls):
        return Length('in', 0.0254)

    @classproperty
    def feet(cls):
        return Length('ft', 0.3048)

    @classproperty
    def yards(cls):
        return Length('yd', 0.9144)

    @classproperty
    def miles(cls):
        return Length('mi', 1609.34)

    @classproperty
    def scandinavian_miles(cls):
        return Length('smi', 10000.0)

    @classproperty
    def lightyears(cls):
        return Length('ly', 9.461e+15)

    @classproperty
    def nautical_miles(cls):
        return Length('NM', 1852.0)

    @classproperty
    def fathoms(cls):
        return Length('ftm', 1.8288)

    @classproperty
    def furlongs(cls):
        return Length('fur', 201.168)

    @classproperty
    def astronomical_units(cls):
        return Length('ua', 1.496e+11)

    @classproperty
    def parsecs(cls):
        return Length('pc', 3.086e+16)
