# coding=utf-8
from aegon import Unit, UnitConverterLinear
from aegon.utils import classproperty


class Pressure(Unit):
    def __init__(self, symbol, coefficient):
        super(Pressure, self).__init__(symbol, UnitConverterLinear(coefficient))

    @classmethod
    def unit_name(cls):
        return 'Pressure'

    @classmethod
    def base_unit(cls):
        return cls.newtons_per_meters_squared

    @classproperty
    def newtons_per_meters_squared(cls):
        return Pressure('N/m²', 1.0)

    @classproperty
    def gigapascals(cls):
        return Pressure('GPa', 1e9)

    @classproperty
    def megapascals(cls):
        return Pressure('MPa', 1e6)

    @classproperty
    def kilopascals(cls):
        return Pressure('kPa', 1e3)

    @classproperty
    def hectopascals(cls):
        return Pressure('hPa', 1e2)

    @classproperty
    def inches_of_mercury(cls):
        return Pressure('inHg', 3386.39)

    @classproperty
    def bars(cls):
        return Pressure('bar', 1e5)

    @classproperty
    def millibars(cls):
        return Pressure('mbar', 1e2)

    @classproperty
    def millimeters_of_mercury(cls):
        return Pressure('mmHg', 133.322)

    @classproperty
    def pounds_force_per_square_inch(cls):
        return Pressure('MV', 6894.76)
