# coding=utf-8
from aegon import Unit, UnitConverterLinear
from aegon.utils import classproperty


class Volume(Unit):
    def __init__(self, symbol, coefficient, constant = 0.0):
        super(Volume, self).__init__(symbol, UnitConverterLinear(coefficient, constant))

    @classmethod
    def unit_name(cls):
        return 'Volume'

    @classmethod
    def base_unit(cls):
        return cls.liters

    @classproperty
    def megaliters(cls):
        return Volume('ML', 1e6)

    @classproperty
    def kiloliters(cls):
        return Volume('kL', 1e3)

    @classproperty
    def liters(cls):
        return Volume('L', 1.0)

    @classproperty
    def deciliters(cls):
        return Volume('dl', 1e-1)

    @classproperty
    def centiliters(cls):
        return Volume('cL', 1e-2)

    @classproperty
    def milliliters(cls):
        return Volume('mL', 1e-3)

    @classproperty
    def cubic_kilometers(cls):
        return Volume('km³', 1e12)

    @classproperty
    def cubic_meters(cls):
        return Volume('m³', 1000.0)

    @classproperty
    def cubic_decimeters(cls):
        return Volume('dm³', 1.0)

    @classproperty
    def cubic_centimeters(cls):
        return Volume('cm³', 0.01)

    @classproperty
    def cubic_millimeters(cls):
        return Volume('mm³', 0.001)

    @classproperty
    def cubic_inches(cls):
        return Volume('in³', 0.0163871)

    @classproperty
    def cubic_feet(cls):
        return Volume('ft³', 28.3168)

    @classproperty
    def cubic_yards(cls):
        return Volume('yd³', 764.555)

    @classproperty
    def cubic_miles(cls):
        return Volume('mi³', 4.168e+12)

    @classproperty
    def acre_feet(cls):
        return Volume('af', 1.233e+6)

    @classproperty
    def bushels(cls):
        return Volume('bsh', 35.2391)

    @classproperty
    def teaspoons(cls):
        return Volume('tsp', 0.00492892)

    @classproperty
    def tablespoons(cls):
        return Volume('tbsp', 0.0147868)

    @classproperty
    def fluid_ounces(cls):
        return Volume('fl oz', 0.0295735)

    @classproperty
    def cups(cls):
        return Volume('cup', 0.24)

    @classproperty
    def pints(cls):
        return Volume('pt', 0.473176)

    @classproperty
    def quarts(cls):
        return Volume('qt', 0.946353)

    @classproperty
    def gallons(cls):
        return Volume('gal', 3.78541)

    @classproperty
    def imperial_teaspoons(cls):
        return Volume('tsp Imperial', 0.00591939)

    @classproperty
    def imperial_tablespoons(cls):
        return Volume('tbsp Imperial', 0.0177582)

    @classproperty
    def imperial_fluid_ounces(cls):
        return Volume('fl oz Imperial', 0.0284131)

    @classproperty
    def imperial_pints(cls):
        return Volume('pt Imperial', 0.568261)

    @classproperty
    def imperial_quarts(cls):
        return Volume('qt Imperial', 1.13652)

    @classproperty
    def imperial_gallons(cls):
        return Volume('gal Imperial', 4.54609)

    @classproperty
    def metric_cups(cls):
        return Volume('metric cup Imperial', 0.25)



